.. image:: https://badge.waffle.io/tomleo/djChoices.png?label=ready&title=Ready 
 :target: https://waffle.io/tomleo/djChoices
 :alt: 'Stories in Ready'

.. image:: https://travis-ci.org/tomleo/djChoices.svg?branch=master
 :target: https://travis-ci.org/tomleo/djChoices
 :alt: 'Travis CI'

djChoices
=========

djChoices was designed to provide the exact same functionality of
model_utils.Choices object but with a slightly different UI.


